===========
Serializers
===========

Serializers allow you to easily turn your data into something which can be rendered by the component.
They help remove much of the boiler plate code which goes into fetching the data,
manipulating it and passing it back to the component.

Wild coeus provides 2 serializers out the box; one for Charts and the other for Tables.


.. toctree::
   :maxdepth: 1
   :caption: Serializers:

   ./chart.rst
   ./table.rst
